"""
    xnbtd
"""

from importlib.metadata import version


__version__ = version('xnbtd')
__author__ = 'André Théo LAURET <andrelauret@eclipse-technology.eu>'


default_app_config = 'xnbtd.apps.XnbtdConfig'
