# Generated by Django 4.1.10 on 2023-08-02 18:13

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="TNT",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="Tour Name")),
                ("date", models.DateField(verbose_name="Tour Date")),
                ("breaks", models.TimeField(verbose_name="Breaks")),
                ("beginning_hour", models.TimeField(verbose_name="Beginning Hour")),
                ("ending_hour", models.TimeField(verbose_name="Ending Hour")),
                (
                    "total_hour",
                    models.FloatField(blank=True, null=True, verbose_name="Total Hour"),
                ),
                ("client_numbers", models.IntegerField(verbose_name="Client numbers")),
                ("refused", models.IntegerField(verbose_name="Refused")),
                ("avp", models.IntegerField(verbose_name="avp")),
                ("cad", models.IntegerField(verbose_name="cad/return")),
                ("totals_clients", models.IntegerField(verbose_name="totals clients")),
                (
                    "occasional_abductions",
                    models.IntegerField(verbose_name="occasional abductions"),
                ),
                (
                    "regular_abductions",
                    models.IntegerField(verbose_name="regular abductions"),
                ),
                (
                    "totals_clients_abductions",
                    models.IntegerField(verbose_name="total clients abductions"),
                ),
                ("kilometers", models.IntegerField(verbose_name="KM/Full")),
                (
                    "linked_user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Deliveryman",
                    ),
                ),
            ],
            options={
                "verbose_name": "TNT",
                "verbose_name_plural": "TNT",
            },
        ),
        migrations.CreateModel(
            name="GLS",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="Tour Name")),
                ("date", models.DateField(verbose_name="Tour Date")),
                ("breaks", models.TimeField(verbose_name="Breaks")),
                ("beginning_hour", models.TimeField(verbose_name="Beginning Hour")),
                ("ending_hour", models.TimeField(verbose_name="Ending Hour")),
                (
                    "total_hour",
                    models.FloatField(blank=True, null=True, verbose_name="Total Hour"),
                ),
                ("points_charges", models.IntegerField(verbose_name="Points Charges")),
                (
                    "points_delivered",
                    models.IntegerField(verbose_name="Points Delivered"),
                ),
                (
                    "packages_charges",
                    models.IntegerField(verbose_name="Packages Charges"),
                ),
                (
                    "packages_delivered",
                    models.IntegerField(verbose_name="Packages Delivered"),
                ),
                ("avp_relay", models.IntegerField(verbose_name="AVP Relay")),
                ("shd", models.IntegerField(verbose_name="SHD")),
                ("eo", models.IntegerField(verbose_name="EO")),
                ("pickup_point", models.IntegerField(verbose_name="Pickup Point")),
                (
                    "linked_user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Deliveryman",
                    ),
                ),
            ],
            options={
                "verbose_name": "GLS",
                "verbose_name_plural": "GLS",
            },
        ),
        migrations.CreateModel(
            name="Ciblex",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="Tour Name")),
                ("date", models.DateField(verbose_name="Tour Date")),
                ("breaks", models.TimeField(verbose_name="Breaks")),
                ("beginning_hour", models.TimeField(verbose_name="Beginning Hour")),
                ("ending_hour", models.TimeField(verbose_name="Ending Hour")),
                (
                    "total_hour",
                    models.FloatField(blank=True, null=True, verbose_name="Total Hour"),
                ),
                ("type", models.CharField(default="LIVRAISONS", max_length=255)),
                ("nights", models.IntegerField(verbose_name="nights")),
                ("days", models.IntegerField(verbose_name="days")),
                ("avp", models.IntegerField(verbose_name="avp")),
                ("spare_part", models.IntegerField(verbose_name="spare part")),
                ("synchro", models.IntegerField(verbose_name="synchro")),
                ("morning_pickup", models.IntegerField(verbose_name="morning pickups")),
                (
                    "linked_user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Deliveryman",
                    ),
                ),
            ],
            options={
                "verbose_name": "Ciblex",
                "verbose_name_plural": "Ciblex",
            },
        ),
        migrations.CreateModel(
            name="ChronopostPickup",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="Tour Name")),
                ("date", models.DateField(verbose_name="Tour Date")),
                ("breaks", models.TimeField(verbose_name="Breaks")),
                ("beginning_hour", models.TimeField(verbose_name="Beginning Hour")),
                ("ending_hour", models.TimeField(verbose_name="Ending Hour")),
                (
                    "total_hour",
                    models.FloatField(blank=True, null=True, verbose_name="Total Hour"),
                ),
                ("esd", models.IntegerField(verbose_name="ESD")),
                ("picked_points", models.IntegerField(verbose_name="Picked Points")),
                ("poste", models.IntegerField(verbose_name="Poste")),
                (
                    "linked_user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Deliveryman",
                    ),
                ),
            ],
            options={
                "verbose_name": "Chronopost Pickup",
                "verbose_name_plural": "Chronopost Pickup",
            },
        ),
        migrations.CreateModel(
            name="ChronopostDelivery",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="Tour Name")),
                ("date", models.DateField(verbose_name="Tour Date")),
                ("breaks", models.TimeField(verbose_name="Breaks")),
                ("beginning_hour", models.TimeField(verbose_name="Beginning Hour")),
                ("ending_hour", models.TimeField(verbose_name="Ending Hour")),
                (
                    "total_hour",
                    models.FloatField(blank=True, null=True, verbose_name="Total Hour"),
                ),
                (
                    "charged_packages",
                    models.IntegerField(verbose_name="Charged Packages"),
                ),
                ("charged_points", models.IntegerField(verbose_name="Charged Points")),
                ("including_ip", models.IntegerField(verbose_name="Including IP")),
                ("relay", models.IntegerField(verbose_name="Relay")),
                (
                    "return_packages",
                    models.IntegerField(verbose_name="Return Packages"),
                ),
                ("return_points", models.IntegerField(verbose_name="Return Points")),
                ("overdue", models.IntegerField(verbose_name="Overdue")),
                ("anomalies", models.IntegerField(verbose_name="Anomalies")),
                ("total_points", models.IntegerField(verbose_name="Total Points")),
                ("full_km", models.IntegerField(verbose_name="Full KM")),
                (
                    "linked_user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Deliveryman",
                    ),
                ),
            ],
            options={
                "verbose_name": "Chronopost Delivery",
                "verbose_name_plural": "Chronopost Delivery",
            },
        ),
    ]
