# Generated by Django 4.2.6 on 2023-10-24 14:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("tours", "0003_remove_chronopostdelivery_total_hour_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="chronopostdelivery",
            name="breaks",
        ),
        migrations.RemoveField(
            model_name="chronopostpickup",
            name="breaks",
        ),
        migrations.RemoveField(
            model_name="ciblex",
            name="breaks",
        ),
        migrations.RemoveField(
            model_name="gls",
            name="breaks",
        ),
        migrations.RemoveField(
            model_name="tnt",
            name="breaks",
        ),
        migrations.CreateModel(
            name="BreakTime",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("object_id", models.PositiveIntegerField()),
                ("time", models.TimeField(verbose_name="Pause Time")),
                (
                    "content_type",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="contenttypes.contenttype",
                    ),
                ),
            ],
        ),
    ]
