# Generated by Django 4.1.10 on 2023-08-18 17:10

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("plannings", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Rest",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("status", models.BooleanField(default=False, verbose_name="Status")),
                ("start_date", models.DateField(verbose_name="Start Date")),
                ("end_date", models.DateField(verbose_name="End Date")),
                (
                    "linked_user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Deliveryman",
                    ),
                ),
            ],
            options={
                "verbose_name": "Rest",
                "verbose_name_plural": "Rests",
                "ordering": ["start_date"],
            },
        ),
    ]
