# Generated by Django 4.1.10 on 2023-09-19 09:46

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("tours", "0002_chronopostdelivery_comments_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="chronopostdelivery",
            name="total_hour",
        ),
        migrations.RemoveField(
            model_name="chronopostpickup",
            name="total_hour",
        ),
        migrations.RemoveField(
            model_name="ciblex",
            name="total_hour",
        ),
        migrations.RemoveField(
            model_name="gls",
            name="total_hour",
        ),
        migrations.RemoveField(
            model_name="tnt",
            name="total_hour",
        ),
    ]
