# Generated by Django 4.1.10 on 2023-08-18 16:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("tours", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="chronopostdelivery",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AddField(
            model_name="chronopostdelivery",
            name="license_plate",
            field=models.CharField(default="XX000XX", max_length=7, verbose_name="License Plate"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="chronopostpickup",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AddField(
            model_name="chronopostpickup",
            name="license_plate",
            field=models.CharField(default="XX000XX", max_length=7, verbose_name="License Plate"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="ciblex",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AddField(
            model_name="ciblex",
            name="license_plate",
            field=models.CharField(default="XX000XX", max_length=7, verbose_name="License Plate"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="gls",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AddField(
            model_name="gls",
            name="full_km",
            field=models.IntegerField(default=0, verbose_name="Full KM"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="gls",
            name="license_plate",
            field=models.CharField(default="XX000XX", max_length=7, verbose_name="License Plate"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="tnt",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AddField(
            model_name="tnt",
            name="license_plate",
            field=models.CharField(default="XX000XX", max_length=7, verbose_name="License Plate"),
            preserve_default=False,
        ),
    ]
