# Generated by Django 4.2.6 on 2023-10-26 05:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("tours", "0005_alter_breaktime_options"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="breaktime",
            name="time",
        ),
        migrations.AddField(
            model_name="breaktime",
            name="end_time",
            field=models.TimeField(default="00:00", verbose_name="End of Break"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="breaktime",
            name="start_time",
            field=models.TimeField(default="00:00", verbose_name="Start of Break"),
            preserve_default=False,
        ),
    ]
